@@ -270,7 +270,7 @@ PyDoc_STRVAR(firebaseMLKitInit_doc,
 	"\n"\
 	"Parameters\n"\
 	"----------\n"\
-	"    mode : int (optional) 0 = FAST ; 1 = ACCURATE");
+	"    mode : int (optional) 1 = FAST ; 2 = ACCURATE");
 
 //firebase MLKit release
 PyDoc_STRVAR(firebaseMLKitRelease_doc,
@@ -302,4 +302,34 @@ PyDoc_STRVAR(firebaseMLKitGetHeadEulerAngle_doc,
 	"\n"\
 	"Returns\n"\
 	"-------\n"\
-	"    result : tuple(y,z)");
\ No newline at end of file
+	"    result : tuple(y,z)");
+
+//get camera size
+PyDoc_STRVAR(cameraGetCameraSize_doc,
+    "get the camera size\n"\
+    "\n"\
+    "igeCamera.getCameraSize()\n"\
+    "\n"\
+    "Returns\n"\
+    "-------\n"\
+    "    result : tuple(w, h)");
+
+//get camera data
+PyDoc_STRVAR(cameraGetCameraData_doc,
+    "Get the camera data\n"\
+    "\n"\
+    "igeCamera.getCameraData()\n"\
+    "\n"\
+    "Returns\n"\
+    "-------\n"\
+    "    result : list(unsigned char)");
+
+//firebase MLKit set contour list need to retrieve
+PyDoc_STRVAR(firebaseMLKitSetContourList_doc,
+	"set contour list need to retrieve \n"\
+	"\n"\
+	"firebaseMLKit.setContourList(value)\n"\
+	"\n"\
+	"Parameters\n"\
+	"----------\n"\
+	"    value : list");
