@@ -243,25 +243,6 @@ void FirebaseImpl::RemoteConfigInit()
 	if(remoteDefaultValues.size() > 0)
 		firebase::remote_config::SetDefaults(&remoteDefaultValues[0], remoteDefaultValues.size());
 
-	// NOTE: Developer mode should not be enabled in production applications.
-	//firebase::remote_config::SetConfigSetting(firebase::remote_config::kConfigSettingDeveloperMode,	"1");
-	//if ((*firebase::remote_config::GetConfigSetting(firebase::remote_config::kConfigSettingDeveloperMode).c_str()) != '1') {
-		//LOG("Failed to enable developer mode");
-	//}
-
-	auto future_result = firebase::remote_config::Fetch(0);
-	while (future_result.status() == firebase::kFutureStatusPending) {
-		LOG("Remote Config ProcessEvents");
-		if (ProcessEvents(1000)) {
-			break;
-		}
-	}
-
-	if (future_result.status() == firebase::kFutureStatusComplete) {		
-		bool activate_result = firebase::remote_config::ActivateFetched();
-		LOG("ActivateFetched %s", activate_result ? "succeeded" : "failed");
-	}
-
 	remoteDefaultValues.clear();
 }
 
